#! /bin/sh -e

# change to the script directory
cd $(dirname "$0")

# initialization
PRODUCT="TyrellN6"
if test -t 0 -a -t 1 ; then
	INTERACTIF=1
else
	INTERACTIF=0
fi
AS_ROOT=0
QUIET=0
VSTDIR="$HOME/.vst/u-he"
WITH_32=0
ARCH=$(uname -m)
NO_PRESETS=0

if test $ARCH = x86_64 ; then
	DIALOG=$PRODUCT/dialog.64
else
	DIALOG=$PRODUCT/dialog.32
fi

usage() {
		echo "usage: ./install.sh <options>..."
        echo -e "  --quiet		  agree the license and install without asking questions"
		echo -e "  --vstdir=<path>	  specify the vst directory. Default: $VSTDIR"
		echo -e "  --as-root		  lets you run this script as root. You have to know what you're doing."
		if test $ARCH = x86_64 ; then
			echo -e "  --without-32		    do not install 32bit version"
		fi
		exit
}

# parse arguments
until test $# -eq 0 ;
do
	case "$1" in
		--quiet)
			QUIET=1
			;;
		--vstdir=*)
			VSTDIR="${1/--vstdir=/}"
			VSTDIR="$(eval echo $VSTDIR)"
			;;
		--help|-h)
			usage
			;;
		--as-root)
			AS_ROOT=1
			;;
		--with-32)
			WITH_32=1
			;;
		--without-32)
			WITH_32=0
			;;
                --no-presets)
                        NO_PRESETS=1
                        ;;
		*)
			echo wrong argument "$1"
			usage
			;;
	esac
	shift
done

# prevent root install
if test "$(whoami)" = root -a "$AS_ROOT" -eq 0 ; then
	if test "$INTERACTIF" -eq 1 ; then
		echo Please do not install as root.
	else
	   	"$DIALOG" message 'Installation error' 'Please do not install as root.' OK
	fi
	exit 1
fi

if test $QUIET -eq 0 -a -r "$PRODUCT/license.txt" ; then
	if test $INTERACTIF -eq 1 ; then
		cat "$PRODUCT/license.txt"
		echo
		echo --------------------------------------------
		echo
		while true
		do
		   	echo -n "Do you agree the license's terms? [y/n] "
	   		read answer
			case "$answer" in
				y|Y|yes|YES|Yes) break;;
				n|N|no|NO|No) exit;;
			esac
		done
	else
		answer=$("$DIALOG" license "$PRODUCT/license.txt")
		if test "$answer" != "yes" ; then
			$DIALOG message "Installation aborted" "Installation aborted." OK
			exit
		fi
	fi
fi

if test "$NO_PRESETS" -eq 1 ; then
        find "$PRODUCT/Presets/$PRODUCT/" \
          \( -type f -a -iname '*.h2p' -a -not -iname 'initialize.h2p' -a -delete \) \
          -o \( -empty -a -delete \)
fi

mkdir -p "$HOME/.u-he/"
cp -R "$PRODUCT" "$HOME/.u-he/"
cp LinuxChangeLog.txt "$HOME/.u-he/$PRODUCT/"
mkdir -p "$VSTDIR"
if test $(uname -m) = x86_64 ; then
        if grep -qi avx /proc/cpuinfo ; then
	        ln -sf "$HOME/.u-he/$PRODUCT/$PRODUCT.64.avx.so" "$VSTDIR/$PRODUCT.64.so"
        else
	        ln -sf "$HOME/.u-he/$PRODUCT/$PRODUCT.64.so" "$VSTDIR/$PRODUCT.64.so"
        fi

	if test $WITH_32 = 1 ; then
		ln -sf "$HOME/.u-he/$PRODUCT/$PRODUCT.32.so" "$VSTDIR/$PRODUCT.32.so"
	fi
else
	ln -sf "$HOME/.u-he/$PRODUCT/$PRODUCT.32.so" "$VSTDIR/$PRODUCT.32.so"
fi

if test "$PRODUCT" = "ZebraHZ" ; then
	ln -snf "$HOME/.u-he/Zebra2/Presets/Zebra2" "$HOME/.u-he/ZebraHZ/Presets/ZebraHZ/Zebra2"
	ln -snf "$HOME/.u-he/Zebra2/Modules/Oscillator" "$HOME/.u-he/ZebraHZ/Modules/Oscillator/Zebra2"
	ln -snf "$HOME/.u-he/Zebra2/Modules/MSEG" "$HOME/.u-he/ZebraHZ/Modules/Oscillator/MSEG"
fi

cat <<EOF >"$HOME/.u-he/$PRODUCT/README-Linux.txt"
Keyboard Modifiers
------------------

In certain cases, Alt+click will not be available to the plugin.
If you notice this happening, please try AtlGr+click instead.

How to uninstall
----------------

To uninstall simply remove the following files/folders:
$HOME/.u-he/$PRODUCT
$VSTDIR/$PRODUCT.*.so

Be sure to back up all your presets before removing any files!
EOF

if test $QUIET -eq 0 ; then
    if test $INTERACTIF -eq 0 ; then
		$DIALOG message "Installation succeed" "Installation succeed." OK
	else
		cat <<EOF

${PRODUCT}'s data were installed to ${HOME}/.u-he/${PRODUCT}
The VST has been installed in: ${VSTDIR}

Have fun with ${PRODUCT} and thank you for installing u-he software!
EOF
	fi
fi
